==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExpressRouteCircuitStatsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains stats associated with the peering.
 * @property primarybytesIn The Primary BytesIn of the peering.
 * @property primarybytesOut The primary BytesOut of the peering.
 * @property secondarybytesIn The secondary BytesIn of the peering.
 * @property secondarybytesOut The secondary BytesOut of the peering.
 */
public data class ExpressRouteCircuitStatsArgs(
    public val primarybytesIn: Output<Double>? = null,
    public val primarybytesOut: Output<Double>? = null,
    public val secondarybytesIn: Output<Double>? = null,
    public val secondarybytesOut: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs =
        com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs.builder()
            .primarybytesIn(primarybytesIn?.applyValue({ args0 -> args0 }))
            .primarybytesOut(primarybytesOut?.applyValue({ args0 -> args0 }))
            .secondarybytesIn(secondarybytesIn?.applyValue({ args0 -> args0 }))
            .secondarybytesOut(secondarybytesOut?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExpressRouteCircuitStatsArgs].
 */
@PulumiTagMarker
public class ExpressRouteCircuitStatsArgsBuilder internal constructor() {
    private var primarybytesIn: Output<Double>? = null

    private var primarybytesOut: Output<Double>? = null

    private var secondarybytesIn: Output<Double>? = null

    private var secondarybytesOut: Output<Double>? = null

    /**
     * @param value The Primary BytesIn of the peering.
     */
    @JvmName("gwdtfvnnbqfohymg")
    public suspend fun primarybytesIn(`value`: Output<Double>) {
        this.primarybytesIn = value
    }

    /**
     * @param value The primary BytesOut of the peering.
     */
    @JvmName("ljxcbgupdluljibm")
    public suspend fun primarybytesOut(`value`: Output<Double>) {
        this.primarybytesOut = value
    }

    /**
     * @param value The secondary BytesIn of the peering.
     */
    @JvmName("jhbwcpuxxexdiusp")
    public suspend fun secondarybytesIn(`value`: Output<Double>) {
        this.secondarybytesIn = value
    }

    /**
     * @param value The secondary BytesOut of the peering.
     */
    @JvmName("chxscihnbtprrdky")
    public suspend fun secondarybytesOut(`value`: Output<Double>) {
        this.secondarybytesOut = value
    }

    /**
     * @param value The Primary BytesIn of the peering.
     */
    @JvmName("irxncdgbechjobwq")
    public suspend fun primarybytesIn(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primarybytesIn = mapped
    }

    /**
     * @param value The primary BytesOut of the peering.
     */
    @JvmName("tkywiuwtroaktrlj")
    public suspend fun primarybytesOut(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primarybytesOut = mapped
    }

    /**
     * @param value The secondary BytesIn of the peering.
     */
    @JvmName("dilrvignnwjjnnas")
    public suspend fun secondarybytesIn(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondarybytesIn = mapped
    }

    /**
     * @param value The secondary BytesOut of the peering.
     */
    @JvmName("dtulbggsynufkitp")
    public suspend fun secondarybytesOut(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondarybytesOut = mapped
    }

    internal fun build(): ExpressRouteCircuitStatsArgs = ExpressRouteCircuitStatsArgs(
        primarybytesIn = primarybytesIn,
        primarybytesOut = primarybytesOut,
        secondarybytesIn = secondarybytesIn,
        secondarybytesOut = secondarybytesOut,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExpressRouteCircuitStatsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Contains stats associated with the peering.
 * @property primarybytesIn The Primary BytesIn of the peering.
 * @property primarybytesOut The primary BytesOut of the peering.
 * @property secondarybytesIn The secondary BytesIn of the peering.
 * @property secondarybytesOut The secondary BytesOut of the peering.
 */
public data class ExpressRouteCircuitStatsArgs(
    public val primarybytesIn: Output<Double>? = null,
    public val primarybytesOut: Output<Double>? = null,
    public val secondarybytesIn: Output<Double>? = null,
    public val secondarybytesOut: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs =
        com.pulumi.azurenative.network.inputs.ExpressRouteCircuitStatsArgs.builder()
            .primarybytesIn(primarybytesIn?.applyValue({ args0 -> args0 }))
            .primarybytesOut(primarybytesOut?.applyValue({ args0 -> args0 }))
            .secondarybytesIn(secondarybytesIn?.applyValue({ args0 -> args0 }))
            .secondarybytesOut(secondarybytesOut?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ExpressRouteCircuitStatsArgs].
 */
@PulumiTagMarker
public class ExpressRouteCircuitStatsArgsBuilder internal constructor() {
    private var primarybytesIn: Output<Double>? = null

    private var primarybytesOut: Output<Double>? = null

    private var secondarybytesIn: Output<Double>? = null

    private var secondarybytesOut: Output<Double>? = null

    /**
     * @param value The Primary BytesIn of the peering.
     */
    @JvmName("mimnnlbaamuwdlee")
    public suspend fun primarybytesIn(`value`: Output<Double>) {
        this.primarybytesIn = value
    }

    /**
     * @param value The primary BytesOut of the peering.
     */
    @JvmName("igtcunospvrlexyr")
    public suspend fun primarybytesOut(`value`: Output<Double>) {
        this.primarybytesOut = value
    }

    /**
     * @param value The secondary BytesIn of the peering.
     */
    @JvmName("hbgqvsontopljssw")
    public suspend fun secondarybytesIn(`value`: Output<Double>) {
        this.secondarybytesIn = value
    }

    /**
     * @param value The secondary BytesOut of the peering.
     */
    @JvmName("ghewsnthpgfhdbwl")
    public suspend fun secondarybytesOut(`value`: Output<Double>) {
        this.secondarybytesOut = value
    }

    /**
     * @param value The Primary BytesIn of the peering.
     */
    @JvmName("mtvwndyqdogjmvmg")
    public suspend fun primarybytesIn(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primarybytesIn = mapped
    }

    /**
     * @param value The primary BytesOut of the peering.
     */
    @JvmName("npemgvllvcwknaeb")
    public suspend fun primarybytesOut(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.primarybytesOut = mapped
    }

    /**
     * @param value The secondary BytesIn of the peering.
     */
    @JvmName("foygdasmxuubalkw")
    public suspend fun secondarybytesIn(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondarybytesIn = mapped
    }

    /**
     * @param value The secondary BytesOut of the peering.
     */
    @JvmName("hfihspvybwhncxfc")
    public suspend fun secondarybytesOut(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secondarybytesOut = mapped
    }

    internal fun build(): ExpressRouteCircuitStatsArgs = ExpressRouteCircuitStatsArgs(
        primarybytesIn = primarybytesIn,
        primarybytesOut = primarybytesOut,
        secondarybytesIn = secondarybytesIn,
        secondarybytesOut = secondarybytesOut,
    )
}
